//
// file      : gfx1_4L.c
// author    : Ian Forse
// date      : 26-MAY-2004
// purpose   : Demonstration of the SP 5-GFX1
// includes  : pic.h, delay.h, delay.c, gfx1_ser_dr.c, gfx1_ser_dr.h, gfx_4line.c
// notes     : 
// compiler  : Hi tech Compiler V8.00PL3
//
// Copyright (C) 2004 Ian Forse
//
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.

// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
// USA

#include <pic.h>
__CONFIG (3F72h);

#define switch RB0

#include "gfx1_ser_dr.h"
#include "delay.h"
#include "delay.c"
#include "gfx1_ser_dr.c"
#include "gfx_4line.c"

__EEPROM_DATA(0x1F, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00);


main()
{
	unsigned char  col, page, c, num_col, i, vol;
	ADCON1 = 0x84; 		// Set port E0/1/2 digital - leave rest as ADC
	gfx1_start_up();
	TRISB0 = 1;
	RBPU = 0;
	gfx1_clear_all();
	
	// Setup display contrast, this stays on for about 16s.  To cycle through the
	// values connect Pin RB0 to 0V, RBO is pulled up internally.  The last setting
	// is saved into the PIC 16F877 internal EEPROM.
	
	c = gfx1_4l_1 (0, 24, ('S'));			// 4 Lines of text
	c = gfx1_4l_1 (0, 34, ('P'));
	c = gfx1_4l_1 (0, 44, ('5'));
	c = gfx1_4l_1 (0, 54, (' '));
	c = gfx1_4l_1 (0, 64, ('G'));
	c = gfx1_4l_1 (0, 74, ('F'));
	c = gfx1_4l_1 (0, 84, ('X'));
	c = gfx1_4l_1 (0, 94, ('1'));
	c = gfx1_4l_1 (2, 34, ('L'));
	c = gfx1_4l_1 (2, 44, ('a'));
	c = gfx1_4l_1 (2, 54, ('s'));
	c = gfx1_4l_1 (2, 64, ('c'));
	c = gfx1_4l_1 (2, 74, ('a'));
	c = gfx1_4l_1 (2, 84, ('r'));
	c = gfx1_4l_1 (4, 9,  ('E'));
	c = gfx1_4l_1 (4, 19, ('l'));
	c = gfx1_4l_1 (4, 29, ('e'));
	c = gfx1_4l_1 (4, 39, ('c'));
	c = gfx1_4l_1 (4, 49, ('t'));
	c = gfx1_4l_1 (4, 59, ('r'));
	c = gfx1_4l_1 (4, 69, ('o'));
	c = gfx1_4l_1 (4, 79, ('n'));
	c = gfx1_4l_1 (4, 89, ('i'));
	c = gfx1_4l_1 (4, 99, ('c'));
	c = gfx1_4l_1 (4, 109,('s'));
	c = gfx1_4l_1 (6, 4,  ('B'));
	c = gfx1_4l_1 (6, 14, ('y'));
	c = gfx1_4l_1 (6, 24, (' '));
	c = gfx1_4l_1 (6, 34, ('I'));
	c = gfx1_4l_1 (6, 44, ('a'));
	c = gfx1_4l_1 (6, 54, ('n'));
	c = gfx1_4l_1 (6, 64, (' '));
	c = gfx1_4l_1 (6, 74, ('F'));
	c = gfx1_4l_1 (6, 84, ('o'));
	c = gfx1_4l_1 (6, 94, ('r'));
	c = gfx1_4l_1 (6, 104,('s'));
	c = gfx1_4l_1 (6, 114,('e'));	
	
	vol = EEPROM_READ(0x00);
	for (i=0; i<63; i++)
	{
		if ( !switch )
		{
			DelayMs(50); 				// debounce delay
			if ( !switch )
			{
				vol++;
				if (vol > 0x3F) vol = 0x00;
				gfx1_write_command (0x81);	// Volume Control Double Command
				gfx1_write_command (vol);	// as detailed in start-up
			}
		}
		DelayMs(250);
	}
	eeprom_write(0x00, vol);				// save setting to PIC EEPROM

	// Creates a demo with each character between ASCII 32 & 127 being displayed
	// The display shows 12 characters per line and after 4 lines the display is
	// cleared and restarts on the first line
	while(1)
	{
		gfx1_clear_all();
		col = 0;
		page = 0;
		for (i=0x20; i<0x7F; i++)
		{
			if (col > 118)
			{
				col = 0;
				page = page + 2;
				if (page > 7)
				{
					page = 0;
					gfx1_clear_all();
				}
			}
			num_col = gfx1_4l_1 (page, col, i);
			col = col + num_col;
			DelayMs(150);
		}
	}
}


